# Copyright 2005-2019 ECMWF.

# EFAS: Average, accumulation, and/or extreme values or other statistically processed values at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval

include "grib2/template.4.parameter_postproc.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.statistical.def"
