# Automatically generated by ./create_def.pl, do not edit
#Total convective Precipitation
'Total convective Precipitation' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 156 ;
	 stepType = "accum" ;
	}
#Total large scale precipitation
'Total large scale precipitation' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 157 ;
	 stepType = "accum" ;
	}
#Convective Available Potential Energy instantaneous
'Convective Available Potential Energy instantaneous' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 160 ;
}
