# Copyright 2005-2019 ECMWF.
#
# This software is licensed under the terms of the Apache Licence Version 2.0
# which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
# 
# In applying this licence, ECMWF does not waive the privileges and immunities granted to it by
# virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
#

# This gets updated twice a year by WMO.
# See http://www.wmo.int/pages/prog/www/WMOCodes/WMO306_vI2/LatestVERSION/LatestVERSION.html
constant tablesVersionLatest = 24 : edition_specific;

constant million = 1000000 : hidden;
constant grib2divider   = 1000000;
alias extraDimensionPresent=zero;
alias is_tigge = zero;
alias is_s2s = zero;
transient is_efas = 0;
transient angleSubdivisions=grib2divider;  # micro degrees
alias angularPrecision=angleSubdivisions : hidden;

meta gts_header gts_header() : no_copy,hidden,read_only;
meta gts_TTAAii gts_header(20,6) : no_copy,hidden,read_only;
meta gts_CCCC gts_header(27,4) : no_copy,hidden,read_only;
meta gts_ddhh00 gts_header(32,6) : no_copy,hidden,read_only;

transient  missingValue   = 9999;
constant ieeeFloats   = 1 : edition_specific;
constant isHindcast = 0;

include "grib2/section.0.def";

template core "grib2/sections.def";

#if(!new())
#{
  #lookup[4] endOfProduct(0);
  #while(endOfProduct != `7777`)
  #{
    #template core "grib2/sections.def";
    #lookup[4] endOfProduct(0);
  #}
#}

template section_8 "grib2/section.8.def";
