# Copyright 2005-2019 ECMWF.

# TEMPLATE 3.130, Irregular Latitude/longitude grid

include "grib2/template.3.shape_of_the_earth.def";

points list(numberOfDataPoints) {
    signed[4] latitude;
    signed[4] longitude;
}
