# Automatically generated by ./create_def.pl, do not edit
#Total convective Precipitation
'85001156' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 156 ;
	 stepType = "accum" ;
	}
#Total large scale precipitation
'85001157' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 157 ;
	 stepType = "accum" ;
	}
#Convective Available Potential Energy instantaneous
'85001160' = {
	 table2Version = 1 ;
	 indicatorOfParameter = 160 ;
}
