# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.14, Derived forecasts based on a cluster of ensemble members over a circular area at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval

include "grib2/template.4.parameter.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.derived.def"
include "grib2/template.4.circular_cluster.def"
include "grib2/template.4.statistical.def"

ensembleForecastNumbersList list(numberOfForecastsInTheCluster) {
  unsigned[1] ensembleForecastNumbers : dump;
}
