# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.0, Analysis or forecast at a horizontal level or in a horizontal layer at a point in time

include "grib2/template.4.parameter.def";
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def";
