# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.1, Individual ensemble forecast, control and perturbed, at a horizontal level or in a horizontal layer at a point in time

include "grib2/template.4.parameter.def"
include "grib2/template.4.point_in_time.def";
include "grib2/template.4.horizontal.def"
include "grib2/template.4.eps.def"
