# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.91, Categorical forecasts at a horizontal level or in a horizontal layer in a continuous or non-continuous time interval

include "grib2/template.4.parameter.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.categorical.def"
include "grib2/template.4.statistical.def"
