# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.1101, Hovmöller-type grid with averaging or other statistical processing

include "grib2/template.4.parameter.def"
include "grib2/template.4.horizontal.def"
include "grib2/template.4.statistical.def"
