# Copyright 2005-2019 ECMWF.

# Predefined grid 26

constant Ni = 72;
constant Nj = 19;

constant longitudeOfFirstGridPoint = 0;
constant longitudeOfLastGridPoint = 355000;

constant latitudeOfFirstGridPoint = -90000;
constant latitudeOfLastGridPoint = 0;

constant iDirectionIncrement = 5000;
constant jDirectionIncrement = 5000;

constant numberOfDataPoints=1368;
constant numberOfValues=1297 ;
