# Copyright 2005-2019 ECMWF.

# GRID DEFINITION latitude/longitude grid - equidistant cylindrical or Plate Carree projection

# grib 1 -> 2
constant gridDefinitionTemplateNumber     = 0;

template commonBlock "grib1/grid_definition_latlon.def";

# Padding - See GRIB-370
ascii[4] zero : read_only;
