# Copyright 2005-2019 ECMWF.

# GRID DEFINITION stretched and rotated latitude/longitude grids
# grib 1 -> 2
constant gridDefinitionTemplateNumber     = 3;

template commonBlock "grib1/grid_definition_latlon.def";

ascii[4] zero : read_only;

# Rotation parameters
include "grib1/grid_rotation.def"

# Stretching parameters
include "grib1/grid_stretching.def"
