# Copyright 2005-2019 ECMWF.

# TEMPLATE 4.1100, Hovmöller-type grid with no averaging or other statistical processing

include "grib2/template.4.parameter.def"
include "grib2/template.4.horizontal.def"
